@@ -151,7 +151,7 @@ class TaskAssignator:
                     self.new_process,
                     simple_fargs_out)
             )
-            print(f"Msg mangaer task {task}")
+            print(f"Msg managaer task {task}")
             if not loop.is_running():
                 loop.run_until_complete(asyncio.gather(task))
         except Exception as ex:
